You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by at...@apache.org on 2013/10/15 16:59:21 UTC

svn commit: r1532375 [3/4] - in /commons/proper/scxml/trunk: ./ src/main/java/org/apache/commons/scxml/ src/main/java/org/apache/commons/scxml2/ src/main/java/org/apache/commons/scxml2/env/ src/main/java/org/apache/commons/scxml2/env/faces/ src/main/ja...

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/core-engine.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/core-engine.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/core-engine.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/core-engine.xml Tue Oct 15 14:59:18 2013
@@ -32,14 +32,14 @@
    <subsection name="Usage">
      <p>The <code>SCXMLExecutor</code> is usually initialized as follows:</p>
      <pre>
-        //import org.apache.commons.scxml.Context;
-        //import org.apache.commons.scxml.ErrorReporter;
-        //import org.apache.commons.scxml.Evaluator;
-        //import org.apache.commons.scxml.EventDispatcher;
-        //import org.apache.commons.scxml.SCXMLExecutor;
-        //import org.apache.commons.scxml.SCXMLListener;
-        //import org.apache.commons.scxml.model.SCXML;
-        //import org.apache.commons.scxml.model.ModelException;
+        //import org.apache.commons.scxml2.Context;
+        //import org.apache.commons.scxml2.ErrorReporter;
+        //import org.apache.commons.scxml2.Evaluator;
+        //import org.apache.commons.scxml2.EventDispatcher;
+        //import org.apache.commons.scxml2.SCXMLExecutor;
+        //import org.apache.commons.scxml2.SCXMLListener;
+        //import org.apache.commons.scxml2.model.SCXML;
+        //import org.apache.commons.scxml2.model.ModelException;
 
         SCXMLExecutor exec = null;
         try {
@@ -67,7 +67,7 @@
      for further details about contexts, evaluators and root contexts.</p>
 
      <p>Commons SCXML provides an
-     <a href="../apidocs/org/apache/commons/scxml/EventDispatcher.html">EventDispatcher</a>
+     <a href="../apidocs/org/apache/commons/scxml2/EventDispatcher.html">EventDispatcher</a>
      interface for wiring the behavior of SCXML &lt;send&gt; and
      &lt;cancel&gt; actions. This allows users to define custom target "types"
      as long as they handle the callbacks on the <code>EventDispatcher</code>
@@ -77,14 +77,14 @@
      &lt;send&gt; usage.</p>
 
      <p>The
-     <a href="../apidocs/org/apache/commons/scxml/ErrorReporter.html">ErrorReporter</a>
+     <a href="../apidocs/org/apache/commons/scxml2/ErrorReporter.html">ErrorReporter</a>
      interface is used by Commons SCXML for reporting SCXML errors to the host
      environment, and contains the definition of commonly occuring errors
      while executing SCXML documents. It is primarily used for passive usages
      such as logging.</p>
 
      <p>Commons SCXML also allows listeners
-     (<a href="../apidocs/org/apache/commons/scxml/SCXMLListener.html">SCXMLListener</a>)
+     (<a href="../apidocs/org/apache/commons/scxml2/SCXMLListener.html">SCXMLListener</a>)
      to be registered with the <code>SCXMLExecutor</code>, which are informed
      about the progress of the state machine via <code>onEntry</code> and
      <code>onExit</code> notifications for <code>State</code>s, as
@@ -94,7 +94,7 @@
      <p>Commons SCXML provides basic implementations of the
      <code>EventDispatcher</code>, <code>ErrorReporter</code>, and
      <code>SCXMLListener</code> interfaces in the
-     <a href="../apidocs/org/apache/commons/scxml/env/package-summary.html">env package</a>,
+     <a href="../apidocs/org/apache/commons/scxml2/env/package-summary.html">env package</a>,
      which simply log all the events received. Commons SCXML uses
      Commons Logging.</p>
 
@@ -104,7 +104,7 @@
      usecase demands.</p>
 
      <p>The <code>SCXMLExecutor</code> Javadoc is available
-     <a href="../apidocs/org/apache/commons/scxml/SCXMLExecutor.html">
+     <a href="../apidocs/org/apache/commons/scxml2/SCXMLExecutor.html">
      here</a>.
      </p>
    </subsection>

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/core-events.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/core-events.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/core-events.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/core-events.xml Tue Oct 15 14:59:18 2013
@@ -41,9 +41,9 @@
      <p>An event &quot;foo.bar&quot; may be fired on the engine as
      follows:</p>
      <pre>
-        //import org.apache.commons.scxml.SCXMLExecutor;
-        //import org.apache.commons.scxml.TriggerEvent;
-        //import org.apache.commons.scxml.model.ModelException;
+        //import org.apache.commons.scxml2.SCXMLExecutor;
+        //import org.apache.commons.scxml2.TriggerEvent;
+        //import org.apache.commons.scxml2.model.ModelException;
 
         // where &quot;exec&quot; is the SCXMLExecutor instance
         TriggerEvent te = new TriggerEvent("foo.bar",
@@ -68,19 +68,19 @@
      conditions or executable content while the engine is processing the
      event. The payload can be any user-defined type.</p>
      <pre>
-        //import org.apache.commons.scxml.SCXMLExecutor;
-        //import org.apache.commons.scxml.TriggerEvent;
-        //import org.apache.commons.scxml.model.ModelException;
-
-        // where "exec" is the SCXMLExecutor instance
-        // and "foo" is an object (payload) with an accessible property "bar"
-        TriggerEvent te = new TriggerEvent("event.with.payload",
-                              TriggerEvent.SIGNAL_EVENT, foo);
-        try {
-            exec.triggerEvent(te);
-        } catch (ModelException me) {
-            // The events left the engine in inconsistent state
-        }
+       //import org.apache.commons.scxml2.SCXMLExecutor;
+       //import org.apache.commons.scxml2.TriggerEvent;
+       //import org.apache.commons.scxml2.model.ModelException;
+
+       // where "exec" is the SCXMLExecutor instance
+       // and "foo" is an object (payload) with an accessible property "bar"
+       TriggerEvent te = new TriggerEvent("event.with.payload",
+       TriggerEvent.SIGNAL_EVENT, foo);
+       try {
+       exec.triggerEvent(te);
+       } catch (ModelException me) {
+       // The events left the engine in inconsistent state
+       }
      </pre>
 
      <p>The payload in the above example can now be used in expressions,
@@ -114,10 +114,10 @@
      <code>Status</code> is queried for state machine run to completion.</p>
 
      <pre>
-        //import org.apache.commons.scxml.SCXMLExecutor;
-        //import org.apache.commons.scxml.Status;
+        //import org.apache.commons.scxml2.SCXMLExecutor;
+        //import org.apache.commons.scxml2.Status;
 
-        // where &quot;exec&quot; is the SCXMLExecutor instance    
+        // where &quot;exec&quot; is the SCXMLExecutor instance
         Status status = exec.getCurrentStatus();
         if (status.isFinal()) {
             // run to completion, release cached objects
@@ -125,10 +125,10 @@
      </pre>
 
      <p>The <code>TriggerEvent</code> Javadoc is available
-     <a href="../apidocs/org/apache/commons/scxml/TriggerEvent.html">
+     <a href="../apidocs/org/apache/commons/scxml2/TriggerEvent.html">
      here</a>.<br/>
      The <code>Status</code> Javadoc is available
-     <a href="../apidocs/org/apache/commons/scxml/Status.html">
+     <a href="../apidocs/org/apache/commons/scxml2/Status.html">
      here</a><br/>
      </p>
    </subsection>

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/core-parser.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/core-parser.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/core-parser.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/core-parser.xml Tue Oct 15 14:59:18 2013
@@ -27,7 +27,7 @@
 
   <section name="Commons SCXML - Parsing SCXML documents for Commons SCXML">
     <p>Commons SCXML provides its own implementation of the
-    <a href="http://commons.apache.org/scxml/apidocs/org/apache/commons/scxml/model/package-summary.html">
+    <a href="http://commons.apache.org/scxml/apidocs/org/apache/commons/scxml2/model/package-summary.html">
     Java object model for SCXML</a>
     and a configured <a href="http://commons.apache.org/digester">
     Digester</a> that can parse SCXML documents into that object model.</p>
@@ -38,9 +38,9 @@
      <pre>
         //import java.io.IOException;
         //import java.net.URL;
-        //import org.apache.commons.scxml.io.SCXMLParser;
-        //import org.apache.commons.scxml.model.ModelException;
-        //import org.apache.commons.scxml.model.SCXML;
+        //import org.apache.commons.scxml2.io.SCXMLParser;
+        //import org.apache.commons.scxml2.model.ModelException;
+        //import org.apache.commons.scxml2.model.SCXML;
         //import org.xml.sax.ErrorHandler;
         //import org.xml.sax.SAXException;
 
@@ -74,13 +74,13 @@
      <p>The SCXMLParser exposes other convenience methods which can handle
      a SCXML document specified using its &quot;real path&quot; on the local
      system, in which case an additional 
-     <code>org.apache.commons.SCXML.PathResolver</code>parameter needs to be
+     <code>org.apache.commons.scxml2.PathResolver</code>parameter needs to be
      supplied for resolving relative document references or as an
      <code>InputSource</code>, in which case there is no path resolution,
      so the document must be a standalone document.</p>
 
      <p>The <code>SCXMLParser</code> Javadoc is available
-     <a href="../apidocs/org/apache/commons/scxml/io/SCXMLParser.html">
+     <a href="../apidocs/org/apache/commons/scxml2/io/SCXMLParser.html">
      here</a>.
      </p>
     </subsection>

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/custom-actions.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/custom-actions.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/custom-actions.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/custom-actions.xml Tue Oct 15 14:59:18 2013
@@ -54,31 +54,31 @@
     <p>A custom action in the Commons SCXML implementation has access to:
      <ul>
       <li>The current
-          <a href="../apidocs/org/apache/commons/scxml/Context.html">Context</a>
+          <a href="../apidocs/org/apache/commons/scxml2/Context.html">Context</a>
           (and hence, the values of variables in the current Context).
       </li>
       <li>Any other Context within the document, provided the id of the
           parent &lt;state&gt; is known.
       </li>
       <li>The expression
-          <a href="../apidocs/org/apache/commons/scxml/Evaluator.html">Evaluator</a>
+          <a href="../apidocs/org/apache/commons/scxml2/Evaluator.html">Evaluator</a>
           for this document, and hence the ability to evaluate a given
           expression against the current or a identifiable Context.
       </li>
       <li>The list of other actions in this
-          <a href="../apidocs/org/apache/commons/scxml/model/Executable.html">Executable</a>
+          <a href="../apidocs/org/apache/commons/scxml2/model/Executable.html">Executable</a>
           .</li>
       <li>The "root" Context, to examine any variable values in the
           "document environment".</li>
       <li>The
-          <a href="../apidocs/org/apache/commons/scxml/EventDispatcher.html">EventDispatcher</a>,
+          <a href="../apidocs/org/apache/commons/scxml2/EventDispatcher.html">EventDispatcher</a>,
           to send or cancel events.</li>
       <li>The
-          <a href="../apidocs/org/apache/commons/scxml/ErrorReporter.html">ErrorReporter</a>,
+          <a href="../apidocs/org/apache/commons/scxml2/ErrorReporter.html">ErrorReporter</a>,
           to report any errors (that the ErrorReporter knows how to handle).</li>
       <li>The histories, for any identifiable &lt;history&gt;.</li>
       <li>The
-          <a href="../apidocs/org/apache/commons/scxml/NotificationRegistry.html">NotificationRegistry</a>,
+          <a href="../apidocs/org/apache/commons/scxml2/NotificationRegistry.html">NotificationRegistry</a>,
           to obtain the list of listeners attached to identifiable
           "observers".</li>
       <li>The engine log, to log any information it needs to.</li>
@@ -102,7 +102,7 @@
       value of the name attribute when it executes.</p>
 
     <p>A simple example is
-      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/custom-hello-world-01.xml">here</a>
+      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/custom-hello-world-01.xml">here</a>
       .</p>
 
    </subsection>
@@ -110,11 +110,11 @@
    <subsection name="Custom action implementation">
 
     <p>A custom action must extend the Commons SCXML
-       <a href="../apidocs/org/apache/commons/scxml/model/Action.html">Action</a>
+       <a href="../apidocs/org/apache/commons/scxml2/model/Action.html">Action</a>
        abstract base class.</p>
 
     <p>Here is the Java source for our custom
-       <a href="../xref-test/org/apache/commons/scxml/model/Hello.html">Hello</a>
+       <a href="../xref-test/org/apache/commons/scxml2/model/Hello.html">Hello</a>
        action. The execute() method contains the logging statement.</p>
 
    </subsection>
@@ -148,7 +148,7 @@
     <p>This approach can only be used if the custom
        rule has no body content (child "tags") or if the custom action
        implements the
-       <a href="../apidocs/org/apache/commons/scxml/model/ExternalContent.html">ExternalContent</a>
+       <a href="../apidocs/org/apache/commons/scxml2/model/ExternalContent.html">ExternalContent</a>
        interface, in which case, any body content gets read into a list
        of DOM nodes. For any other requirements, the digester rules
        can be added by directly by obtaining a Digester instance with the
@@ -162,7 +162,7 @@
    <subsection name="Read in the 'custom' SCXML document">
 
     <p>For documents without custom actions, the utility methods of the
-       <a href="../apidocs/org/apache/commons/scxml/io/SCXMLParser.html">SCXMLParser</a>
+       <a href="../apidocs/org/apache/commons/scxml2/io/SCXMLParser.html">SCXMLParser</a>
        should be used. That section is
        <a href="core-parser.html">here</a>.</p>
 

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/custom-semantics.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/custom-semantics.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/custom-semantics.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/custom-semantics.xml Tue Oct 15 14:59:18 2013
@@ -33,10 +33,10 @@
    <subsection name="Pluggable semantics">
 
     <p>The Commons SCXML state machine engine is really a tuple, the
-    <a href="../apidocs/org/apache/commons/scxml/SCXMLExecutor.html">SCXMLExecutor</a>
+    <a href="../apidocs/org/apache/commons/scxml2/SCXMLExecutor.html">SCXMLExecutor</a>
     (an API that new users can code to, and is almost always sufficient)
     accompanied by a
-    <a href="../apidocs/org/apache/commons/scxml/SCXMLSemantics.html">SCXMLSemantics</a>
+    <a href="../apidocs/org/apache/commons/scxml2/SCXMLSemantics.html">SCXMLSemantics</a>
     implementation (an API that advanced users can code to, to change the
     engine behavior to suit their needs).</p>
     

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/datamodel.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/datamodel.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/datamodel.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/datamodel.xml Tue Oct 15 14:59:18 2013
@@ -187,7 +187,7 @@
     </pre>
 
     <p>Commons SCXML creates a new
-    <a href="../apidocs/org/apache/commons/scxml/Context.html">Context</a>
+    <a href="../apidocs/org/apache/commons/scxml2/Context.html">Context</a>
     for each state that needs one, and each data element may be thought of
     as a <code>org.w3c.dom.Node</code> object placed in the corresponding
     Context. The datamodel element at the document root populates the

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/scxml-documents.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/scxml-documents.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/scxml-documents.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/scxml-documents.xml Tue Oct 15 14:59:18 2013
@@ -54,7 +54,7 @@
   <section name="Hello World">
 
    <p>Here is the canonical
-      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/hello-world.xml">hello world example</a>
+      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/hello-world.xml">hello world example</a>
       for SCXML. The interesting bits are:</p>
 
    <pre>
@@ -163,7 +163,7 @@
    <p>States can contain states, so we can think of an
       SCXML document as a recursive transition network. Here is
       a snippet (here is the entire version of this
-      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/env/jexl/microwave-01.xml">microwave example</a>
+      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/microwave-01.xml">microwave example</a>
       ):</p>
 
    <pre>
@@ -221,7 +221,7 @@
       can become a state machine in its own right -- that are "active"
       at the same time. Here is
       a relevant snippet (the entire version of this
-      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/env/jexl/microwave-02.xml">parallel microwave example</a>
+      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/microwave-02.xml">parallel microwave example</a>
       ):</p>
 
    <pre>
@@ -281,7 +281,7 @@
 
    <p>The Commons SCXML implementation allows you to register custom actions.
       Here is the Commons SCXML
-      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/custom-hello-world-02.xml">hello world example using a custom action</a>.
+      <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/custom-hello-world-02.xml">hello world example using a custom action</a>.
       The interesting bits are:</p>
 
    <pre>

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/side-effect-el.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/side-effect-el.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/side-effect-el.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/side-effect-el.xml Tue Oct 15 14:59:18 2013
@@ -41,26 +41,26 @@
    context of evaluation and an evaluator, which gives us the following
    usage:</p>
    <pre>
-   //import org.apache.commons.scxml.Context;
-   //import org.apache.commons.scxml.Evaluator;
-   //import org.apache.commons.scxml.SCXMLExpressionException;
-   //import org.apache.commons.scxml.env.jsp.ELContext;
-   //import org.apache.commons.scxml.env.jsp.ELEvaluator;
+     //import org.apache.commons.scxml2.Context;
+     //import org.apache.commons.scxml2.Evaluator;
+     //import org.apache.commons.scxml2.SCXMLExpressionException;
+     //import org.apache.commons.scxml2.env.jsp.ELContext;
+     //import org.apache.commons.scxml2.env.jsp.ELEvaluator;
 
-   Context context = new ELContext();
-   // Say we have an instance 'foo' of type Foo which
-   // has a property 'bar' of type String
-   context.set("foo", foo);
+     Context context = new ELContext();
+     // Say we have an instance 'foo' of type Foo which
+     // has a property 'bar' of type String
+     context.set("foo", foo);
 
-   Evaluator evaluator = new ELEvaluator();
+     Evaluator evaluator = new ELEvaluator();
 
-   String bar = null;
-   try {
+     String bar = null;
+     try {
      bar = (String) evaluator.eval(context, "${foo.bar}");
-   } catch (SCXMLExpressionException see) {
+     } catch (SCXMLExpressionException see) {
      // Commons SCXML wraps the underlying exception,
      // in this case, a javax.servlet.jsp.el.ELException
-   }
+     }
    </pre>
   </section> 
 

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/testing-standalone.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/testing-standalone.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/testing-standalone.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/testing-standalone.xml Tue Oct 15 14:59:18 2013
@@ -56,9 +56,9 @@
     commons-logging-1.1.1.jar;commons-scxml-0.9.jar;
     commons-jexl-1.1.jar
 
-    <a href="../xref/org/apache/commons/scxml/test/StandaloneJexlExpressions.html">org.apache.commons.scxml.test.StandaloneJexlExpressions</a>
+    <a href="../xref/org/apache/commons/scxml2/test/StandaloneJexlExpressions.html">org.apache.commons.scxml2.test.StandaloneJexlExpressions</a>
 
-    <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/env/jexl/microwave-01.xml">microwave01.xml</a>
+    <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/microwave-01.xml">microwave01.xml</a>
     </pre>
 
    </subsection>
@@ -78,9 +78,9 @@
     commons-logging-1.0.4.jar;commons-scxml-1.0-SNAPSHOT.jar;
     commons-el-1.0.jar;jsp-api-2.0.jar
 
-    <a href="../xref/org/apache/commons/scxml/test/StandaloneElExpressions.html">org.apache.commons.scxml.test.StandaloneElExpressions</a>
+    <a href="../xref/org/apache/commons/scxml2/test/StandaloneElExpressions.html">org.apache.commons.scxml2.test.StandaloneElExpressions</a>
 
-    <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/env/jsp/microwave-01.xml">microwave01.xml</a>
+    <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/microwave-01.xml">microwave01.xml</a>
     </pre>
 
    </subsection>
@@ -93,7 +93,7 @@
    </p>
 
    <p>A few examples are available as part of the 
-   <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/">
+   <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/">
    Commons SCXML test suite</a> (look in env.jexl and env.jsp child packages as well).</p>
 
   </section> 

Modified: commons/proper/scxml/trunk/src/site/xdoc/guide/using-commons-scxml.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/guide/using-commons-scxml.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/guide/using-commons-scxml.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/guide/using-commons-scxml.xml Tue Oct 15 14:59:18 2013
@@ -100,7 +100,7 @@
     <p>Commons SCXML allows processes to register listeners for
     notifications for state machine execution events (entry, exit,
     transition). Listeners implement the
-    <a href="../apidocs/org/apache/commons/scxml/SCXMLListener.html">SCXMLListener</a>
+    <a href="../apidocs/org/apache/commons/scxml2/SCXMLListener.html">SCXMLListener</a>
     interface. This approach is useful for:</p>
 
     <ul>
@@ -120,7 +120,7 @@
     considered as params for the event target.</p>
 
     <p>The callbacks are received on the
-    <a href="../apidocs/org/apache/commons/scxml/EventDispatcher.html">EventDispatcher</a>
+    <a href="../apidocs/org/apache/commons/scxml2/EventDispatcher.html">EventDispatcher</a>
     associated with the SCXMLExecutor. The EventDispatcher implementation
     activates the necessary target, which then performs the activity needed to
     make progress.</p>

Modified: commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android.xml Tue Oct 15 14:59:18 2013
@@ -72,8 +72,8 @@
   <section name="Building the Android Application">
    <subsection name="The Stopwatch Logic">
     <p>As already mentioned this usecase is based on the stopwatch example. It uses 
-    both the <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/env/stopwatch.xml">stopwatch.xml</a> 
-    and the <a href="../xref-test/org/apache/commons/scxml/env/StopWatch.html">StopWatch.java</a>.</p>
+    both the <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/stopwatch.xml">stopwatch.xml</a>
+    and the <a href="../xref-test/org/apache/commons/scxml2/env/StopWatch.html">StopWatch.java</a>.</p>
    </subsection>
    <subsection name="The Stopwatch UI">
     <p>Here is the UI definition for the stopwatch: <a href="scxml-stopwatch-on-android/stopwatch_display.xml">stopwatch_display.xml</a>.

Modified: commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/AndroidManifest.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/AndroidManifest.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/AndroidManifest.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/AndroidManifest.xml Tue Oct 15 14:59:18 2013
@@ -16,7 +16,7 @@
  * limitations under the License.
 -->
 
-<manifest xmlns:android="http://schemas.android.com/apk/res/android" package="org.apache.commons.scxml.samples.android">
+<manifest xmlns:android="http://schemas.android.com/apk/res/android" package="org.apache.commons.scxml2.samples.android">
 	
 	
 	<application android:icon="@drawable/icon">

Modified: commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/StopWatchActivity.java.txt
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/StopWatchActivity.java.txt?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/StopWatchActivity.java.txt (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch-on-android/StopWatchActivity.java.txt Tue Oct 15 14:59:18 2013
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.scxml.samples.android;
+package org.apache.commons.scxml2.samples.android;
 
 import java.util.Timer;
 import java.util.TimerTask;
 
-import org.apache.commons.scxml.env.StopWatch;
-import org.apache.commons.scxml.samples.android.R;
+import org.apache.commons.scxml2.env.StopWatch;
+import org.apache.commons.scxml2.samples.android.R;
 
 import android.app.Activity;
 import android.os.Bundle;

Modified: commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch.xml?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch.xml (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/usecases/scxml-stopwatch.xml Tue Oct 15 14:59:18 2013
@@ -73,15 +73,15 @@
    <subsection name="The SCXML document">
     <p>The SCXML document is then, a simple serialization of
        the "model" above:
-       <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml/env/stopwatch.xml">stopwatch.xml</a>.
+       <a href="http://svn.apache.org/repos/asf/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/stopwatch.xml">stopwatch.xml</a>.
     </p>
    </subsection>
 
    <subsection name="The Stopwatch class">
     <p>Here is the class that implements the stopwatch behavior,
-       <a href="../xref-test/org/apache/commons/scxml/env/StopWatch.html">StopWatch.java</a>.
+       <a href="../xref-test/org/apache/commons/scxml2/env/StopWatch.html">StopWatch.java</a>.
        The class extends
-       <a href="../xref/org/apache/commons/scxml/env/AbstractStateMachine.html">AbstractStateMachine.java</a>,
+       <a href="../xref/org/apache/commons/scxml2/env/AbstractStateMachine.html">AbstractStateMachine.java</a>,
        which provides one approach for providing the base functionality
        needed by classes representing stateful entities. Points to note
        in the StopWatch class are:
@@ -96,7 +96,7 @@
 
    <subsection name="The Stopwatch UI">
     <p>Here is the UI for our demonstration,
-       <a href="../xref-test/org/apache/commons/scxml/env/StopWatchDisplay.html">StopWatchDisplay.java</a>.
+       <a href="../xref-test/org/apache/commons/scxml2/env/StopWatchDisplay.html">StopWatchDisplay.java</a>.
        Points to note here are:
        <ul>
         <li>The UI is "backed" by a StopWatch instance.</li>

Modified: commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java Tue Oct 15 14:59:18 2013
@@ -23,7 +23,7 @@
  * Apache Shale dependencies -
  * http://shale.apache.org/dependencies.html
  */
-package org.apache.commons.scxml.usecases;
+package org.apache.commons.scxml2.usecases;
 
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -43,18 +43,18 @@ import org.apache.commons.digester.Rule;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import org.apache.commons.scxml.SCXMLDigester;
-import org.apache.commons.scxml.SCXMLExecutor;
-import org.apache.commons.scxml.TriggerEvent;
-import org.apache.commons.scxml.env.SimpleDispatcher;
-import org.apache.commons.scxml.env.SimpleErrorHandler;
-import org.apache.commons.scxml.env.SimpleErrorReporter;
-import org.apache.commons.scxml.env.SimpleSCXMLListener;
-import org.apache.commons.scxml.env.faces.SessionContext;
-import org.apache.commons.scxml.env.faces.ShaleDialogELEvaluator;
-import org.apache.commons.scxml.model.ModelException;
-import org.apache.commons.scxml.model.SCXML;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.SCXMLDigester;
+import org.apache.commons.scxml2.SCXMLExecutor;
+import org.apache.commons.scxml2.TriggerEvent;
+import org.apache.commons.scxml2.env.SimpleDispatcher;
+import org.apache.commons.scxml2.env.SimpleErrorHandler;
+import org.apache.commons.scxml2.env.SimpleErrorReporter;
+import org.apache.commons.scxml2.env.SimpleSCXMLListener;
+import org.apache.commons.scxml2.env.faces.SessionContext;
+import org.apache.commons.scxml2.env.faces.ShaleDialogELEvaluator;
+import org.apache.commons.scxml2.model.ModelException;
+import org.apache.commons.scxml2.model.SCXML;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 import org.apache.shale.dialog.Globals;
 import org.apache.shale.dialog.Status;
@@ -75,7 +75,7 @@ import org.xml.sax.InputSource;
  *     for your web application such that the
  *     &quot;<code>faces-config/application/navigation-handler</code>&quot;
  *     entry points to
- *     &quot;<code>org.apache.commons.scxml.usecases.SCXMLDialogNavigationHandler</code>&quot;
+ *     &quot;<code>org.apache.commons.scxml2.usecases.SCXMLDialogNavigationHandler</code>&quot;
  *     (with the appropriate package name, if you changed it).
  *    </li>
  *    <li>As an alternative to (1) and (2), you can place a <i>jar</i> in the 

Modified: commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java.txt
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java.txt?rev=1532375&r1=1532374&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java.txt (original)
+++ commons/proper/scxml/trunk/src/site/xdoc/usecases/shale-dialogs/SCXMLDialogNavigationHandler.java.txt Tue Oct 15 14:59:18 2013
@@ -23,7 +23,7 @@
  * Apache Shale dependencies -
  * http://shale.apache.org/dependencies.html
  */
-package org.apache.commons.scxml.usecases;
+package org.apache.commons.scxml2.usecases;
 
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -43,18 +43,18 @@ import org.apache.commons.digester.Rule;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import org.apache.commons.scxml.SCXMLDigester;
-import org.apache.commons.scxml.SCXMLExecutor;
-import org.apache.commons.scxml.TriggerEvent;
-import org.apache.commons.scxml.env.SimpleDispatcher;
-import org.apache.commons.scxml.env.SimpleErrorHandler;
-import org.apache.commons.scxml.env.SimpleErrorReporter;
-import org.apache.commons.scxml.env.SimpleSCXMLListener;
-import org.apache.commons.scxml.env.faces.SessionContext;
-import org.apache.commons.scxml.env.faces.ShaleDialogELEvaluator;
-import org.apache.commons.scxml.model.ModelException;
-import org.apache.commons.scxml.model.SCXML;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.SCXMLDigester;
+import org.apache.commons.scxml2.SCXMLExecutor;
+import org.apache.commons.scxml2.TriggerEvent;
+import org.apache.commons.scxml2.env.SimpleDispatcher;
+import org.apache.commons.scxml2.env.SimpleErrorHandler;
+import org.apache.commons.scxml2.env.SimpleErrorReporter;
+import org.apache.commons.scxml2.env.SimpleSCXMLListener;
+import org.apache.commons.scxml2.env.faces.SessionContext;
+import org.apache.commons.scxml2.env.faces.ShaleDialogELEvaluator;
+import org.apache.commons.scxml2.model.ModelException;
+import org.apache.commons.scxml2.model.SCXML;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 import org.apache.shale.dialog.Globals;
 import org.apache.shale.dialog.Status;
@@ -75,7 +75,7 @@ import org.xml.sax.InputSource;
  *     for your web application such that the
  *     &quot;<code>faces-config/application/navigation-handler</code>&quot;
  *     entry points to
- *     &quot;<code>org.apache.commons.scxml.usecases.SCXMLDialogNavigationHandler</code>&quot;
+ *     &quot;<code>org.apache.commons.scxml2.usecases.SCXMLDialogNavigationHandler</code>&quot;
  *     (with the appropriate package name, if you changed it).
  *    </li>
  *    <li>As an alternative to (1) and (2), you can place a <i>jar</i> in the

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/BuiltinTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/BuiltinTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/BuiltinTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/BuiltinTest.java Tue Oct 15 14:59:18 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.util.HashSet;
 import java.util.Set;
 
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/EventDataTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/EventDataTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/NamespacePrefixedXPathsTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/NamespacePrefixedXPathsTest.java Tue Oct 15 14:59:18 2013
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.net.URL;
 import java.util.Set;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.env.jsp.ELContext;
-import org.apache.commons.scxml.env.jsp.ELEvaluator;
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.env.jsp.ELContext;
+import org.apache.commons.scxml2.env.jsp.ELEvaluator;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 /**
  * Unit tests for namespace prefixes in XPaths pointing bits in a &lt;data&gt;.
@@ -48,9 +48,9 @@ public class NamespacePrefixedXPathsTest
     @Override
     public void setUp() throws Exception {
         datamodel03jexl = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/datamodel-03.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/datamodel-03.xml");
         datamodel03jsp = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jsp/datamodel-03.xml");
+            getResource("org/apache/commons/scxml2/env/jsp/datamodel-03.xml");
         exec01 = SCXMLTestHelper.getExecutor(datamodel03jexl);
         exec02 = SCXMLTestHelper.getExecutor(datamodel03jsp, new ELContext(), new ELEvaluator());
     }

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCInstanceTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCInstanceTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCInstanceTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCInstanceTest.java Tue Oct 15 14:59:18 2013
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.util.HashSet;
 import java.util.Set;
 
 import org.apache.commons.jexl.JexlContext;
-import org.apache.commons.scxml.env.SimpleContext;
-import org.apache.commons.scxml.env.jexl.JexlEvaluator;
-import org.apache.commons.scxml.model.History;
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.env.SimpleContext;
+import org.apache.commons.scxml2.env.jexl.JexlEvaluator;
+import org.apache.commons.scxml2.model.History;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLExecutorTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLExecutorTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLHelperTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLHelperTest.java Tue Oct 15 14:59:18 2013
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.util.HashSet;
 import java.util.Set;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.env.MockErrorReporter;
-import org.apache.commons.scxml.env.SimpleErrorReporter;
-import org.apache.commons.scxml.model.Parallel;
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.TransitionTarget;
-import org.apache.commons.scxml.semantics.ErrorConstants;
+import org.apache.commons.scxml2.env.MockErrorReporter;
+import org.apache.commons.scxml2.env.SimpleErrorReporter;
+import org.apache.commons.scxml2.model.Parallel;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.TransitionTarget;
+import org.apache.commons.scxml2.semantics.ErrorConstants;
 
 public class SCXMLHelperTest extends TestCase {
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLTestHelper.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLTestHelper.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLTestHelper.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLTestHelper.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -32,15 +32,15 @@ import javax.xml.parsers.DocumentBuilder
 
 import junit.framework.Assert;
 
-import org.apache.commons.scxml.env.SimpleDispatcher;
-import org.apache.commons.scxml.env.Tracer;
-import org.apache.commons.scxml.env.jexl.JexlEvaluator;
-import org.apache.commons.scxml.io.SCXMLReader;
-import org.apache.commons.scxml.io.SCXMLReader.Configuration;
-import org.apache.commons.scxml.model.CustomAction;
-import org.apache.commons.scxml.model.ModelException;
-import org.apache.commons.scxml.model.SCXML;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.env.SimpleDispatcher;
+import org.apache.commons.scxml2.env.Tracer;
+import org.apache.commons.scxml2.env.jexl.JexlEvaluator;
+import org.apache.commons.scxml2.io.SCXMLReader;
+import org.apache.commons.scxml2.io.SCXMLReader.Configuration;
+import org.apache.commons.scxml2.model.CustomAction;
+import org.apache.commons.scxml2.model.ModelException;
+import org.apache.commons.scxml2.model.SCXML;
+import org.apache.commons.scxml2.model.TransitionTarget;
 import org.w3c.dom.Document;
 import org.xml.sax.InputSource;
 /**

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/StatusTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/StatusTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/StatusTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/StatusTest.java Tue Oct 15 14:59:18 2013
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.model.State;
+import org.apache.commons.scxml2.model.State;
 
 public class StatusTest extends TestCase {
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TieBreakerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TieBreakerTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/LogUtilsTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/LogUtilsTest.java Tue Oct 15 14:59:18 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.Transition;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.Transition;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 public class LogUtilsTest extends TestCase {
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/MockErrorReporter.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/MockErrorReporter.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/MockErrorReporter.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/MockErrorReporter.java Tue Oct 15 14:59:18 2013
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
-import org.apache.commons.scxml.ErrorReporter;
+import org.apache.commons.scxml2.ErrorReporter;
 
 public class MockErrorReporter implements ErrorReporter {
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/SimpleContextTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/SimpleContextTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/SimpleContextTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/SimpleContextTest.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatch.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatch.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatch.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatch.java Tue Oct 15 14:59:18 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
 import java.util.Set;
 import java.util.Timer;
 import java.util.TimerTask;
 
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 /**
  * A SCXML document driven stop watch.
@@ -52,7 +52,7 @@ public class StopWatch extends AbstractS
 
     public StopWatch() {
         super(StopWatch.class.getClassLoader().
-            getResource("org/apache/commons/scxml/env/stopwatch.xml"));
+            getResource("org/apache/commons/scxml2/env/stopwatch.xml"));
     }
 
     // Each method below is the activity corresponding to a state in the

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchDisplay.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchDisplay.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchDisplay.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchDisplay.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
 import java.awt.BorderLayout;
 import java.awt.Graphics;
@@ -85,9 +85,9 @@ public class StopWatchDisplay extends JF
 
     private void setupUI() {
         URL imageURL = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/stopwatch.gif");
+            getResource("org/apache/commons/scxml2/env/stopwatch.gif");
         URL iconURL = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/stopwatchicon.gif");
+            getResource("org/apache/commons/scxml2/env/stopwatchicon.gif");
         Toolkit kit = Toolkit.getDefaultToolkit();
         watchImage = kit.createImage(imageURL);
         watchIcon = kit.createImage(iconURL);

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/StopWatchTest.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
 
 import junit.framework.TestCase;

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/faces/SessionContextTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/faces/SessionContextTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/faces/SessionContextTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/faces/SessionContextTest.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.faces;
+package org.apache.commons.scxml2.env.faces;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSBindingsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSBindingsTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSBindingsTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSBindingsTest.java Tue Oct 15 14:59:18 2013
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.scxml.env.javascript;
+package org.apache.commons.scxml2.env.javascript;
 
 import java.util.AbstractMap;
 import java.util.HashMap;
@@ -26,7 +26,7 @@ import javax.script.SimpleBindings;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.Context;
+import org.apache.commons.scxml2.Context;
 
 /**
  * JUnit 3 test case for the JSBinding implementation that imports

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSContextTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSContextTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSContextTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSContextTest.java Tue Oct 15 14:59:18 2013
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.scxml.env.javascript;
+package org.apache.commons.scxml2.env.javascript;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.env.SimpleContext;
+import org.apache.commons.scxml2.env.SimpleContext;
 
 /**
  * JUnit 3 test case for the JSContext SCXML Context implementation for

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSEvaluatorTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSEvaluatorTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSEvaluatorTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSEvaluatorTest.java Tue Oct 15 14:59:18 2013
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.scxml.env.javascript;
+package org.apache.commons.scxml2.env.javascript;
 
 import java.io.StringReader;
 
@@ -25,12 +25,12 @@ import javax.xml.xpath.XPathFactory;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.Context;
-import org.apache.commons.scxml.Evaluator;
-import org.apache.commons.scxml.SCXMLExecutor;
-import org.apache.commons.scxml.SCXMLExpressionException;
-import org.apache.commons.scxml.io.SCXMLReader;
-import org.apache.commons.scxml.model.SCXML;
+import org.apache.commons.scxml2.Context;
+import org.apache.commons.scxml2.Evaluator;
+import org.apache.commons.scxml2.SCXMLExecutor;
+import org.apache.commons.scxml2.SCXMLExpressionException;
+import org.apache.commons.scxml2.io.SCXMLReader;
+import org.apache.commons.scxml2.model.SCXML;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSExampleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSExampleTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSExampleTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/javascript/JSExampleTest.java Tue Oct 15 14:59:18 2013
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.scxml.env.javascript;
+package org.apache.commons.scxml2.env.javascript;
 
 import java.net.URL;
 import java.util.ArrayList;
@@ -26,21 +26,21 @@ import java.util.Set;
 import junit.framework.TestCase;
 
 import org.apache.commons.logging.Log;
-import org.apache.commons.scxml.Context;
-import org.apache.commons.scxml.ErrorReporter;
-import org.apache.commons.scxml.Evaluator;
-import org.apache.commons.scxml.EventDispatcher;
-import org.apache.commons.scxml.SCInstance;
-import org.apache.commons.scxml.SCXMLExecutor;
-import org.apache.commons.scxml.SCXMLExpressionException;
-import org.apache.commons.scxml.SCXMLTestHelper;
-import org.apache.commons.scxml.TriggerEvent;
-import org.apache.commons.scxml.model.Action;
-import org.apache.commons.scxml.model.CustomAction;
-import org.apache.commons.scxml.model.ModelException;
-import org.apache.commons.scxml.model.SCXML;
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.Context;
+import org.apache.commons.scxml2.ErrorReporter;
+import org.apache.commons.scxml2.Evaluator;
+import org.apache.commons.scxml2.EventDispatcher;
+import org.apache.commons.scxml2.SCInstance;
+import org.apache.commons.scxml2.SCXMLExecutor;
+import org.apache.commons.scxml2.SCXMLExpressionException;
+import org.apache.commons.scxml2.SCXMLTestHelper;
+import org.apache.commons.scxml2.TriggerEvent;
+import org.apache.commons.scxml2.model.Action;
+import org.apache.commons.scxml2.model.CustomAction;
+import org.apache.commons.scxml2.model.ModelException;
+import org.apache.commons.scxml2.model.SCXML;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 /**
  * SCXML application for the example JavaScript scripts.
@@ -62,7 +62,7 @@ public class JSExampleTest extends TestC
     @Override
     public void setUp() {
         example01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/javascript/example-01.xml");
+            getResource("org/apache/commons/scxml2/env/javascript/example-01.xml");
     }
 
     /**

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlContextTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlContextTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlContextTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlContextTest.java Tue Oct 15 14:59:18 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.jexl;
+package org.apache.commons.scxml2.env.jexl;
 
 import java.util.HashMap;
 import java.util.Map;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.Builtin;
+import org.apache.commons.scxml2.Builtin;
 
 public class JexlContextTest extends TestCase {
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlEvaluatorTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlEvaluatorTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlEvaluatorTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/JexlEvaluatorTest.java Tue Oct 15 14:59:18 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.jexl;
+package org.apache.commons.scxml2.env.jexl;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.Context;
-import org.apache.commons.scxml.Evaluator;
-import org.apache.commons.scxml.SCXMLExpressionException;
+import org.apache.commons.scxml2.Context;
+import org.apache.commons.scxml2.Evaluator;
+import org.apache.commons.scxml2.SCXMLExpressionException;
 
 public class JexlEvaluatorTest extends TestCase {
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/StaticMethodTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/StaticMethodTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/StaticMethodTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/StaticMethodTest.java Tue Oct 15 14:59:18 2013
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.jexl;
+package org.apache.commons.scxml2.env.jexl;
 
 import java.net.URL;
 import java.util.Set;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.Context;
-import org.apache.commons.scxml.SCXMLExecutor;
-import org.apache.commons.scxml.SCXMLTestHelper;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.Context;
+import org.apache.commons.scxml2.SCXMLExecutor;
+import org.apache.commons.scxml2.SCXMLTestHelper;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 public class StaticMethodTest extends TestCase {
 
@@ -40,7 +40,7 @@ public class StaticMethodTest extends Te
     @Override
     public void setUp() {
         staticmethod = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/static-method.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/static-method.xml");
     }
 
     /**

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/datamodel-03.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/datamodel-03.xml?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/datamodel-03.xml (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jexl/datamodel-03.xml Tue Oct 15 14:59:18 2013
@@ -17,7 +17,7 @@
 -->
 <!-- A fictitious state machine used by test cases. Meant to illustrate
      prefixed XPath expressions in the Commons SCXML Data() function.
-     Used by org.apache.commons.scxml.NamespacePrefixedPathsTest.
+     Used by org.apache.commons.scxml2.NamespacePrefixedPathsTest.
      Also serves as testing the underlying functionality of the
      underlying parsing technology (here, Digester 1.8) -->
 <scxml xmlns="http://www.w3.org/2005/07/scxml"

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/ELEvaluatorTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/ELEvaluatorTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/ELEvaluatorTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/ELEvaluatorTest.java Tue Oct 15 14:59:18 2013
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.jsp;
+package org.apache.commons.scxml2.env.jsp;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.Context;
-import org.apache.commons.scxml.Evaluator;
-import org.apache.commons.scxml.SCXMLExpressionException;
+import org.apache.commons.scxml2.Context;
+import org.apache.commons.scxml2.Evaluator;
+import org.apache.commons.scxml2.SCXMLExpressionException;
 
 public class ELEvaluatorTest extends TestCase {
 

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/MockJspContext.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/MockJspContext.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/MockJspContext.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/MockJspContext.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.jsp;
+package org.apache.commons.scxml2.env.jsp;
 
 import java.util.Enumeration;
 import java.util.HashMap;

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/RootContextTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/RootContextTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/datamodel-03.xml (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/datamodel-03.xml Tue Oct 15 14:59:18 2013
@@ -17,7 +17,7 @@
 -->
 <!-- A fictitious state machine used by test cases. Meant to illustrate
      prefixed XPath expressions in the Commons SCXML Data() function.
-     Used by org.apache.commons.scxml.NamespacePrefixedPathsTest
+     Used by org.apache.commons.scxml2.NamespacePrefixedPathsTest
      Also serves as testing the underlying functionality of the
      underlying parsing technology (here, Digester 1.8) -->
 <scxml xmlns="http://www.w3.org/2005/07/scxml"

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/rhino/RhinoContextTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/rhino/RhinoContextTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/rhino/RhinoContextTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/rhino/RhinoContextTest.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.rhino;
+package org.apache.commons.scxml2.env.rhino;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -25,8 +25,8 @@ import javax.xml.parsers.DocumentBuilder
 import junit.framework.Assert;
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.Context;
-import org.apache.commons.scxml.Evaluator;
+import org.apache.commons.scxml2.Context;
+import org.apache.commons.scxml2.Evaluator;
 import org.mozilla.javascript.Script;
 import org.mozilla.javascript.Scriptable;
 import org.w3c.dom.Document;
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/EventDataTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/EventDataTest.java Tue Oct 15 14:59:18 2013
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.net.URL;
 import java.util.Set;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.env.SimpleScheduler;
-import org.apache.commons.scxml.env.Tracer;
-import org.apache.commons.scxml.env.jexl.JexlEvaluator;
-import org.apache.commons.scxml.model.SCXML;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.env.SimpleScheduler;
+import org.apache.commons.scxml2.env.Tracer;
+import org.apache.commons.scxml2.env.jexl.JexlEvaluator;
+import org.apache.commons.scxml2.model.SCXML;
+import org.apache.commons.scxml2.model.TransitionTarget;
 /**
  * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
  * Testing special variable "_eventdata"
  */
 public class EventDataTest extends TestCase {
@@ -48,13 +48,13 @@ public class EventDataTest extends TestC
     @Override
     public void setUp() {
         eventdata01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/eventdata-01.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/eventdata-01.xml");
         eventdata02 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/eventdata-02.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/eventdata-02.xml");
         eventdata03 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/eventdata-03.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/eventdata-03.xml");
         eventdata04 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/eventdata-04.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/eventdata-04.xml");
     }
 
     /**
@@ -14,19 +14,19 @@
 /**
- * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
+ * Unit tests {@link org.apache.commons.scxml2.SCXMLExecutor}.
  * Testing special variable "_eventdata"
  */

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/NamespacePrefixedXPathsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/NamespacePrefixedXPathsTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLExecutorTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLExecutorTest.java Tue Oct 15 14:59:18 2013
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.net.URL;
 import java.util.HashSet;
 import java.util.Set;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.env.SimpleContext;
-import org.apache.commons.scxml.env.jsp.ELEvaluator;
-import org.apache.commons.scxml.model.SCXML;
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.env.SimpleContext;
+import org.apache.commons.scxml2.env.jsp.ELEvaluator;
+import org.apache.commons.scxml2.model.SCXML;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.TransitionTarget;
 /**
  * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
  */
 public class SCXMLExecutorTest extends TestCase {
     /**
@@ -50,37 +50,37 @@ public class SCXMLExecutorTest extends T
     @Override
     public void setUp() {
         microwave01jsp = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jsp/microwave-01.xml");
+            getResource("org/apache/commons/scxml2/env/jsp/microwave-01.xml");
         microwave02jsp = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jsp/microwave-02.xml");
+            getResource("org/apache/commons/scxml2/env/jsp/microwave-02.xml");
         microwave01jexl = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/microwave-01.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/microwave-01.xml");
         microwave02jexl = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/microwave-02.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/microwave-02.xml");
         microwave03jexl = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/microwave-03.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/microwave-03.xml");
         microwave04jexl = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/microwave-04.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/microwave-04.xml");
         microwave05jexl = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/microwave-05.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/microwave-05.xml");
         transitions01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/transitions-01.xml");
+            getResource("org/apache/commons/scxml2/transitions-01.xml");
         transitions02 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/transitions-02.xml");
+            getResource("org/apache/commons/scxml2/transitions-02.xml");
         transitions03 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/transitions-03.xml");
+            getResource("org/apache/commons/scxml2/transitions-03.xml");
         transitions04 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/transitions-04.xml");
+            getResource("org/apache/commons/scxml2/transitions-04.xml");
         transitions05 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/transitions-05.xml");
+            getResource("org/apache/commons/scxml2/transitions-05.xml");
         transitions06 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/transitions-06.xml");
+            getResource("org/apache/commons/scxml2/transitions-06.xml");
         prefix01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/prefix-01.xml");
+            getResource("org/apache/commons/scxml2/prefix-01.xml");
         send01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/send-01.xml");
+            getResource("org/apache/commons/scxml2/send-01.xml");
         send02 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/send-02.xml");
+            getResource("org/apache/commons/scxml2/send-02.xml");
     }
 
     /**
@@ -14,20 +14,20 @@
 /**
- * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
+ * Unit tests {@link org.apache.commons.scxml2.SCXMLExecutor}.
  */
 public class SCXMLExecutorTest extends TestCase {

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLHelperTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/SCXMLHelperTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TieBreakerTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TieBreakerTest.java Tue Oct 15 14:59:18 2013
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.net.URL;
 import java.util.Set;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.model.TransitionTarget;
 /**
  * Unit tests for testing conflict resolution amongst multiple transitions
  * within the {@link org.apache.commons.scxml.SCXMLExecutor}'s default
  * semantics.
  *
  * Upto v0.6, non-deterministic behavior leads to an error condition. Based
@@ -53,17 +53,17 @@ public class TieBreakerTest extends Test
     @Override
     public void setUp() {
         tiebreaker01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/tie-breaker-01.xml");
+            getResource("org/apache/commons/scxml2/tie-breaker-01.xml");
         tiebreaker02 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/tie-breaker-02.xml");
+            getResource("org/apache/commons/scxml2/tie-breaker-02.xml");
         tiebreaker03 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/tie-breaker-03.xml");
+            getResource("org/apache/commons/scxml2/tie-breaker-03.xml");
         tiebreaker04 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/tie-breaker-04.xml");
+            getResource("org/apache/commons/scxml2/tie-breaker-04.xml");
         tiebreaker05 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/tie-breaker-05.xml");
+            getResource("org/apache/commons/scxml2/tie-breaker-05.xml");
         tiebreaker06 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/tie-breaker-06.xml");
+            getResource("org/apache/commons/scxml2/tie-breaker-06.xml");
     }
 
     /**
@@ -14,16 +14,16 @@
 /**
  * Unit tests for testing conflict resolution amongst multiple transitions
- * within the {@link org.apache.commons.scxml.SCXMLExecutor}'s default
+ * within the {@link org.apache.commons.scxml2.SCXMLExecutor}'s default
  * semantics.
  *

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TriggerEventTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TriggerEventTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TriggerEventTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/TriggerEventTest.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.util.Map;
 import java.util.HashMap;
@@ -22,7 +22,7 @@ import java.util.HashMap;
 import junit.framework.TestCase;
 
 /**
  * Unit tests {@link org.apache.commons.scxml.TriggerEvent}.
  */
 public class TriggerEventTest extends TestCase {
     /**
@@ -22,7 +22,7 @@ import java.util.HashMap;
 
 /**
- * Unit tests {@link org.apache.commons.scxml.TriggerEvent}.
+ * Unit tests {@link org.apache.commons.scxml2.TriggerEvent}.
  */
 public class TriggerEventTest extends TestCase {

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WildcardTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WildcardTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WildcardTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WildcardTest.java Tue Oct 15 14:59:18 2013
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.net.URL;
 import java.util.Set;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.model.TransitionTarget;
 /**
  * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
  * Testing wildcard event matching (*)
  */
 public class WildcardTest extends TestCase {
@@ -44,9 +44,9 @@ public class WildcardTest extends TestCa
     @Override
     public void setUp() {
         wildcard01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/wildcard-01.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/wildcard-01.xml");
         wildcard02 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/wildcard-02.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/wildcard-02.xml");
     }
 
     /**
@@ -14,15 +14,15 @@
 /**
- * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
+ * Unit tests {@link org.apache.commons.scxml2.SCXMLExecutor}.
  * Testing wildcard event matching (*)
  */

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WizardsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WizardsTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WizardsTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/WizardsTest.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml;
+package org.apache.commons.scxml2;
 
 import java.io.Serializable;
 import java.net.URL;
@@ -23,14 +23,14 @@ import java.util.Map;
 import java.util.Set;
 
 import junit.framework.TestCase;
-import org.apache.commons.scxml.env.Tracer;
-import org.apache.commons.scxml.env.jexl.JexlContext;
-import org.apache.commons.scxml.env.jexl.JexlEvaluator;
-import org.apache.commons.scxml.model.SCXML;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.env.Tracer;
+import org.apache.commons.scxml2.env.jexl.JexlContext;
+import org.apache.commons.scxml2.env.jexl.JexlEvaluator;
+import org.apache.commons.scxml2.model.SCXML;
+import org.apache.commons.scxml2.model.TransitionTarget;
 import org.w3c.dom.Node;
 /**
  * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
  */
 public class WizardsTest extends TestCase {
     /**
@@ -51,9 +51,9 @@ public class WizardsTest extends TestCas
     @Override
     public void setUp() {
         wizard01 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/wizard-01.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/wizard-01.xml");
         wizard02 = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jexl/wizard-02.xml");
+            getResource("org/apache/commons/scxml2/env/jexl/wizard-02.xml");
     }
 
     /**
@@ -23,14 +23,14 @@ import java.util.Map;
 import org.w3c.dom.Node;
 /**
- * Unit tests {@link org.apache.commons.scxml.SCXMLExecutor}.
+ * Unit tests {@link org.apache.commons.scxml2.SCXMLExecutor}.
  */
 public class WizardsTest extends TestCase {

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractSCXMLListenerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractSCXMLListenerTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractSCXMLListenerTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractSCXMLListenerTest.java Tue Oct 15 14:59:18 2013
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.SCXMLListener;
-import org.apache.commons.scxml.model.State;
-import org.apache.commons.scxml.model.Transition;
-import org.apache.commons.scxml.model.TransitionTarget;
+import org.apache.commons.scxml2.SCXMLListener;
+import org.apache.commons.scxml2.model.State;
+import org.apache.commons.scxml2.model.Transition;
+import org.apache.commons.scxml2.model.TransitionTarget;
 
 /**
  * Unit tests {@link org.apache.commons.scxml.env.AbstractSCXMLListener}.
  */
 public class AbstractSCXMLListenerTest extends TestCase {
     /**
@@ -14,17 +14,17 @@
 
 /**
- * Unit tests {@link org.apache.commons.scxml.env.AbstractSCXMLListener}.
+ * Unit tests {@link org.apache.commons.scxml2.env.AbstractSCXMLListener}.
  */
 public class AbstractSCXMLListenerTest extends TestCase {

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractStateMachineTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractStateMachineTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractStateMachineTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/AbstractStateMachineTest.java Tue Oct 15 14:59:18 2013
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env;
+package org.apache.commons.scxml2.env;
 
 import java.net.URL;
 
 import junit.framework.TestCase;
 
 /**
  * Unit tests {@link org.apache.commons.scxml.env.AbstractStateMachine}.
  */
 public class AbstractStateMachineTest extends TestCase {
 
@@ -14,14 +14,14 @@
 
 /**
- * Unit tests {@link org.apache.commons.scxml.env.AbstractStateMachine}.
+ * Unit tests {@link org.apache.commons.scxml2.env.AbstractStateMachine}.
  */
 public class AbstractStateMachineTest extends TestCase {

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/LogUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/LogUtilsTest.java?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================
--- commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/RootContextTest.java (original)
+++ commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/RootContextTest.java Tue Oct 15 14:59:18 2013
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.scxml.env.jsp;
+package org.apache.commons.scxml2.env.jsp;
 
 import java.net.URL;
 
@@ -22,11 +22,11 @@ import javax.servlet.jsp.JspContext;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.scxml.SCXMLExecutor;
-import org.apache.commons.scxml.SCXMLTestHelper;
+import org.apache.commons.scxml2.SCXMLExecutor;
+import org.apache.commons.scxml2.SCXMLTestHelper;
 
 /**
  * Unit tests {@link org.apache.commons.scxml.env.jsp.RootContext}.
  */
 public class RootContextTest extends TestCase {
     /**
@@ -50,7 +50,7 @@ public class RootContextTest extends Tes
     @Override
     public void setUp() {
         rootCtxSample = this.getClass().getClassLoader().
-            getResource("org/apache/commons/scxml/env/jsp/jsp-rootctx-test.xml");
+            getResource("org/apache/commons/scxml2/env/jsp/jsp-rootctx-test.xml");
         evaluator = new ELEvaluator();
         jspCtx = new MockJspContext();
         jspCtx.setAttribute("foo", "1");
@@ -22,11 +22,11 @@ import javax.servlet.jsp.JspContext;
 
 /**
- * Unit tests {@link org.apache.commons.scxml.env.jsp.RootContext}.
+ * Unit tests {@link org.apache.commons.scxml2.env.jsp.RootContext}.
  */
 public class RootContextTest extends TestCase {

Modified: commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/datamodel-03.xml
URL: http://svn.apache.org/viewvc/commons/proper/scxml/trunk/src/test/java/org/apache/commons/scxml2/env/jsp/datamodel-03.xml?rev=1532375&r1=1532061&r2=1532375&view=diff
==============================================================================